@@ -1,3 +1,3 @@
 console.log(/*#__PURE__*/ React.createElement("h1", {
-    value: "abc\\nas"
+    value: "abc as"
 }, "s"));
